@@ -117,15 +117,34 @@ available_clocksource'
         utils_lib.run_cmd(self, 'dmesg', expect_ret=0, expect_not_kw='Call trace,Call Trace', msg="Check there is no call trace in dmesg")
 
     def test_check_dmesg_unknownsymbol(self):
-        '''
-        bz: 1649215
-        polarion_id:
-        '''
-        utils_lib.run_cmd(self,
-                    'dmesg',
-                    expect_ret=0,
-                    expect_not_kw='Unknown symbol',
-                    msg='Check there is no Unknown symbol in dmesg')
+        """
+        case_name:
+            test_check_dmesg_unknownsymbol
+        case_file:
+            os_tests.tests.test_general_check.TestGeneralCheck.test_check_dmesg_unknownsymbol
+        component:
+            kernel
+        bugzilla_id:
+            1649215, 2018886
+        customer_case_id:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Make sure there is no 'Unknown' keyword from dmesg output.
+            'BOOT_IMAGE' is a know unknow command line parameters, others are not expected.
+            https://lore.kernel.org/all/20210511211009.42259-1-ahalaney@redhat.com/T/#u
+
+        key_steps:
+            # dmesg|grep -i Unknow
+        expect_result:
+            No unknow value found
+        debug_want:
+            # dmesg
+        """
+        utils_lib.check_log(self, 'Unknown symbol,Unknown command line,Unknown,unknown', log_cmd='dmesg')
 
     def test_check_dmesg_nmi(self):
         '''
@@ -276,6 +295,36 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
                 command += result_out[i] + ' '
             self.fail(f'{command}(pid:{lastpid}) have abnormal usage of CPU.')
 
+    def test_check_hostkey_permissions(self):
+        """
+        case_name:
+            test_check_hostkey_permissions
+        case_file:
+            os_tests.tests.test_general_check.TestGeneralCheck.test_check_hostkey_permissions
+        component:
+            ssh
+        bugzilla_id:
+            2013644
+        customer_case_id:
+            True
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check ssh key files permission set are correct.
+        key_steps:
+            # ls -l /etc/ssh/{ssh_host_ecdsa_key,ssh_host_ed25519_key,ssh_host_rsa_key}
+        expect_result:
+            No '-rw-------' found
+        debug_want:
+            N/A
+        """
+        utils_lib.run_cmd(self,
+            "ls -l /etc/ssh/{ssh_host_ecdsa_key,ssh_host_ed25519_key,ssh_host_rsa_key}",
+            expect_not_kw='-rw-------. 1 root root',
+            msg='check ssh key files permission set are correct')
+
     def test_iostat_x(self):
         '''
         case_name:
@@ -423,6 +472,34 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         '''
         utils_lib.check_log(self, 'denied', skip_words='test_check_journalctl_denied', rmt_redirect_stdout=True)
 
+    def test_check_journalctl_disabled(self):
+        """
+        case_name:
+            test_check_journalctl_disabled
+        case_file:
+            os_tests.tests.test_general_check.TestGeneralCheck.test_check_journalctl_disabled
+        component:
+            kernel
+        bugzilla_id:
+            N/A
+        customer_case_id:
+            False
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            - kaslr is enabled by default, check there is no 'KASLR disabled', please ignor this if 'nokaslr' used.
+        key_steps:
+            # journalctl|grep -i 'KASLR disabled'
+        expect_result:
+            "KASLR disabled" not found
+        debug_want:
+            # journalctl
+        """
+        expect_not_kws = 'KASLR disabled'
+        utils_lib.check_log(self, expect_not_kws, skip_words='test_check_journalctl_disabled', rmt_redirect_stdout=True)
+
     def test_check_journalctl_dumpedcore(self):
         '''
         polarion_id:
@@ -662,6 +739,9 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         expected_result:
             No segmentation fault found.
         '''
+        product_id = utils_lib.get_product_id(self)
+        if utils_lib.is_arch(self,arch='aarch64') and float(product_id) < 9:
+            self.skipTest('lsmem of version under el9 does not support arm platform ')
         utils_lib.run_cmd(self, 'lsmem', expect_ret=0, expect_not_kw='Segmentation', msg='check no segfault')
         utils_lib.run_cmd(self, 'lsmem -o NODE', expect_ret=0, expect_not_kw='Segmentation', msg='check no segfault')
 
